@@ -266,7 +266,7 @@ module Net   #:nodoc:
   #     response = http.request request # Net::HTTPResponse object
   #   end
   #
-  # In previous versions of ruby you would need to require 'net/https' to use
+  # In previous versions of Ruby you would need to require 'net/https' to use
   # HTTPS.  This is no longer true.
   #
   # === Proxies
@@ -334,6 +334,7 @@ module Net   #:nodoc:
   #   HTTPResetContent::                    205
   #   HTTPPartialContent::                  206
   #   HTTPMultiStatus::                     207
+  #   HTTPIMUsed::                          226
   # HTTPRedirection::                    3xx
   #   HTTPMultipleChoices::                 300
   #   HTTPMovedPermanently::                301
@@ -384,7 +385,7 @@ module Net   #:nodoc:
   class HTTP < Protocol
 
     # :stopdoc:
-    Revision = %q$Revision: 49378 $.split[1]
+    Revision = %q$Revision: 44079 $.split[1]
     HTTPVersion = '1.1'
     begin
       require 'zlib'
@@ -395,8 +396,8 @@ module Net   #:nodoc:
     end
     # :startdoc:
 
-    # Turns on net/http 1.2 (ruby 1.8) features.
-    # Defaults to ON in ruby 1.8 or later.
+    # Turns on net/http 1.2 (Ruby 1.8) features.
+    # Defaults to ON in Ruby 1.8 or later.
     def HTTP.version_1_2
       true
     end
@@ -671,7 +672,7 @@ module Net   #:nodoc:
     #
     # Sets an output stream for debugging.
     #
-    #   http = Net::HTTP.new
+    #   http = Net::HTTP.new(hostname)
     #   http.set_debug_output $stderr
     #   http.start { .... }
     #
@@ -877,6 +878,7 @@ module Net   #:nodoc:
       s = Timeout.timeout(@open_timeout, Net::OpenTimeout) {
         TCPSocket.open(conn_address, conn_port, @local_host, @local_port)
       }
+      s.setsockopt(Socket::IPPROTO_TCP, Socket::TCP_NODELAY, 1)
       D "opened"
       if use_ssl?
         ssl_parameters = Hash.new
@@ -912,10 +914,7 @@ module Net   #:nodoc:
             @socket.write(buf)
             HTTPResponse.read_new(@socket).value
           end
-          if @ssl_session and
-             Time.now < @ssl_session.time + @ssl_session.timeout
-            s.session = @ssl_session if @ssl_session
-          end
+          s.session = @ssl_session if @ssl_session
           # Server Name Indication (SNI) RFC 3546
           s.hostname = @address if s.respond_to? :hostname=
           Timeout.timeout(@open_timeout, Net::OpenTimeout) { s.connect }
@@ -1027,9 +1026,7 @@ module Net   #:nodoc:
 
     # The proxy URI determined from the environment for this connection.
     def proxy_uri # :nodoc:
-      @proxy_uri ||= URI::HTTP.new(
-        "http".freeze, nil, address, port, nil, nil, nil, nil, nil
-      ).find_proxy
+      @proxy_uri ||= URI("http://#{address}:#{port}").find_proxy
     end
 
     # The address of the proxy server, if one is configured.
@@ -1348,8 +1345,7 @@ module Net   #:nodoc:
     #    puts response.body
     #
     def send_request(name, path, data = nil, header = nil)
-      has_response_body = name != 'HEAD'
-      r = HTTPGenericRequest.new(name,(data ? true : false),has_response_body,path,header)
+      r = HTTPGenericRequest.new(name,(data ? true : false),true,path,header)
       request r, data
     end
 
